# instanzio un oggetto simulatore
set ns [new Simulator]

# definisco il tipo di simulazione
# !! e' solo per la versione di ns2 installata in laboratorio EDA
$ns set cosim_type 0

# creo un file per NAM con le statistiche
set nf [open out.nam w]
$ns namtrace-all $nf

# definisco la procedura di chiusura
# 1. invoca la fine della simulazione
# 2. chiude le statistiche
# 3. lancia NAM
# 4. termina la simulazione
proc finish {} {
	global ns nf
	$ns flush-trace
	close $nf
	exec nam out.nam &
	exit 0
}

# descrivo la topologia della rete
# creo 2 nodi
set n0 [$ns node]
set n1 [$ns node]

# tipo link  // da // a // capacita' // ritardo // coda router  
$ns duplex-link $n0 $n1 1Mb 10ms DropTail

# nel modello ISO/OSI e in base alla terminologia TCP/IP
# nodi : livello 3 (trasmissione/ricezione di pacchetti e routing)
# link : livello 2
# host : livello 4 (trasporto) + livello applicazione 
#         (creazione/ricezione di dati)

# creo un agente UDP su n0
set udp0 [new Agent/UDP]
$ns attach-agent $n0 $udp0

# creo un agente collettore di pacchetti su n1
set null0 [new Agent/Null]
$ns attach-agent $n1 $null0

# connetto i 2 agenti 
# n.b. livello 4 host-to-host, non e' necessario che 2 i rispettivi nodi siano 
# fisicamente adiacenti
$ns connect $udp0 $null0

# creo un'applicazione sopra l'agente UDP
# sorgente di traffico Constant BitRate (CBR) con pacchetti 
# da 500 byte ogni 5ms
set cbr0 [new Application/Traffic/CBR]
$cbr0 set packetSize_ 500
$cbr0 set interval_ 0.005
$cbr0 attach-agent $udp0

# con 'at' inserisco gli eventi di simulazione

# imposto la chiamata alla funzione di chiusura al 5' secondo di simulazione
$ns at 5.0 "finish"

# programmo l'accensione e lo spegnimento della sorgente CBR
$ns at 0.5 "$cbr0 start"
$ns at 4.5 "$cbr0 stop"

# lancio la simulazione
$ns run 
